@@ -21,7 +21,7 @@ suppressWarnings(RNGversion("3.5.0"))
 set.seed(456)
 carseats[sample(seq(NROW(carseats)), 10), "Urban"] <- NA
 
-## ----imputate_na, fig.align='center', fig.width = 6, fig.height = 4-----------
+## ----imputate_na, fig.align='center', fig.width = 7, fig.height = 5-----------
 income <- imputate_na(carseats, Income, US, method = "rpart")
 
 # result of imputation
@@ -33,7 +33,7 @@ summary(income)
 # viz of imputation
 plot(income)
 
-## ----imputate_na2, fig.align='center', fig.width = 6, fig.height = 4----------
+## ----imputate_na2, fig.align='center', fig.width = 7, fig.height = 5----------
 library(mice)
 
 urban <- imputate_na(carseats, Urban, US, method = "mice")
@@ -55,7 +55,7 @@ carseats %>%
   summarise(orig = mean(Income, na.rm = TRUE),
     imputation = mean(Income_imp))
 
-## ----imputate_outlier, fig.align='center', fig.width = 6, fig.height = 4------
+## ----imputate_outlier, fig.align='center', fig.width = 7, fig.height = 5------
 price <- imputate_outlier(carseats, Price, method = "capping")
 
 # result of imputation
@@ -75,7 +75,7 @@ carseats %>%
   summarise(orig = mean(Price, na.rm = TRUE),
     imputation = mean(Price_imp, na.rm = TRUE))
 
-## ----standardization, fig.align='center', fig.width = 6, fig.height = 4-------
+## ----standardization, fig.align='center', fig.width = 7, fig.height = 5-------
 carseats %>% 
   mutate(Income_minmax = transform(carseats$Income, method = "minmax"),
     Sales_minmax = transform(carseats$Sales, method = "minmax")) %>% 
@@ -95,7 +95,7 @@ find_skewness(carseats, value = TRUE)
 # compute the skewness & filtering with threshold
 find_skewness(carseats, value = TRUE, thres = 0.1)
 
-## ----resolving2, fig.align='center', fig.width = 6, fig.height = 4------------
+## ----resolving2, fig.align='center', fig.width = 7, fig.height = 5------------
 Advertising_log = transform(carseats$Advertising, method = "log")
 
 # result of transformation
@@ -105,7 +105,7 @@ summary(Advertising_log)
 # viz of transformation
 plot(Advertising_log)
 
-## ----resolving3, fig.align='center', fig.width = 6, fig.height = 4------------
+## ----resolving3, fig.align='center', fig.width = 7, fig.height = 5------------
 Advertising_log <- transform(carseats$Advertising, method = "log+1")
 
 # result of transformation
@@ -115,7 +115,7 @@ summary(Advertising_log)
 # viz of transformation
 # plot(Advertising_log)
 
-## ----binning, fig.width = 8, fig.height = 6-----------------------------------
+## ----binning, fig.width = 7, fig.height = 5-----------------------------------
 # Binning the carat variable. default type argument is "quantile"
 bin <- binning(carseats$Income)
 # Print bins class object
@@ -150,7 +150,7 @@ carseats %>%
  arrange(desc(freq)) %>%
  head(10)
 
-## ----binning_by, fig.width = 8, fig.height = 5, dpi=300-----------------------
+## ----binning_by, fig.width = 7, fig.height = 5--------------------------------
 library(dplyr)
 
 # optimal binning using character
@@ -191,9 +191,3 @@ knitr::include_graphics('img/trans_agenda_pdf.png')
 ## ----trans_content_pdf, echo=FALSE, out.width='60%', fig.align='center', fig.pos="!h", fig.cap="Data Transformation Report Table and Visualization Example"----
 knitr::include_graphics('img/trans_content_pdf.png')
 
-## ----trans_agenda_html, echo=FALSE, out.width='60%', fig.align='center', fig.pos="!h", fig.cap="Data transformation report titles and table of contents"----
-knitr::include_graphics('img/trans_agenda_html.png')
-
-## ----trans_table_html, echo=FALSE, eval=FALSE, out.width='50%', fig.align='center', fig.pos="!h", fig.cap="Report table example (web)"----
-#  knitr::include_graphics('img/trans_table_html.png')
-
